pub trait TypeAttributes {
// Required methods
fn get_attribute_index(&self, attr_name: &ValueName) -> Option<u32>;
fn get_attribute_type(&self, attr_name: &ValueName) -> Option<Type>;
fn get_method(&self, method_name: String) -> Option<FunctionName>;
fn is_attribute(&self, name: &ValueName) -> bool;
fn is_method(&self, name: String) -> bool;
}Expand description
TypeAttributes type attributes trait.
Used for types declarations.
Required Methods
Sourcefn get_attribute_index(&self, attr_name: &ValueName) -> Option<u32>
fn get_attribute_index(&self, attr_name: &ValueName) -> Option<u32>
Get attribute index by value name for the parent type
Sourcefn get_attribute_type(&self, attr_name: &ValueName) -> Option<Type>
fn get_attribute_type(&self, attr_name: &ValueName) -> Option<Type>
Get attribute type by value name for the parent type
Sourcefn get_method(&self, method_name: String) -> Option<FunctionName>
fn get_method(&self, method_name: String) -> Option<FunctionName>
Get function name for the parent type by method name
Sourcefn is_attribute(&self, name: &ValueName) -> bool
fn is_attribute(&self, name: &ValueName) -> bool
Check is value attribute